==> regexp_parser-0.4.13.tar.gz: regexp_parser-0.4.13/test/parser/test_properties.rb <==
require File.expand_path("../../helpers", __FILE__)

class ParserProperties < Test::Unit::TestCase

  modes = ['p', 'P']
  props = [
    'Alnum',
    'Alpha',
    'Ascii',
    'Blank',
    'Cntrl',
    'Digit',
    'Graph',
    'Lower',
    'Print',
    'Punct',
    'Space',
    'Upper',
    'Word',
    'Xdigit',
    'XPosixPunct',

    'Newline',

    'Any',
    'Assigned',

    'L',
    'Letter',

    'Lu',
    'Uppercase_Letter',

    'Ll',
    'Lowercase_Letter',

    'Lt',
    'Titlecase_Letter',

    'Lm',
    'Modifier_Letter',

    'Lo',
    'Other_Letter',

    'M',
    'Mark',

    'Mn',
    'Nonspacing_Mark',

    'Mc',
    'Spacing_Mark',

    'Me',
    'Enclosing_Mark',

    'N',
    'Number',

    'Nd',
    'Decimal_Number',

    'Nl',
    'Letter_Number',

    'No',
    'Other_Number',

    'P',
    'Punctuation',

    'Pc',
    'Connector_Punctuation',

    'Pd',
    'Dash_Punctuation',

    'Ps',
    'Open_Punctuation',

    'Pe',
    'Close_Punctuation',

    'Pi',
    'Initial_Punctuation',

    'Pf',
    'Final_Punctuation',

    'Po',
    'Other_Punctuation',

    'S',
    'Symbol',

    'Sm',
    'Math_Symbol',

    'Sc',
    'Currency_Symbol',

    'Sk',
    'Modifier_Symbol',

    'So',
    'Other_Symbol',

    'Z',
    'Separator',

    'Zs',
    'Space_Separator',

    'Zl',
    'Line_Separator',

    'Zp',
    'Paragraph_Separator',

    'C',
    'Other',

    'Cc',
    'Control',

    'Cf',
    'Format',

    'Cs',
    'Surrogate',

    'Co',
    'Private_Use',

    'Cn',
    'Unassigned',

    'Age=1.1',
    'Age=2.0',
    'Age=2.1',
    'Age=3.0',
    'Age=3.1',
    'Age=3.2',
    'Age=4.0',
    'Age=4.1',
    'Age=5.0',
    'Age=5.1',
    'Age=5.2',
    'Age=6.0',
    'Age=7.0',
    'Age=8.0',
    'Age=9.0',
    'Age=10.0',

    'ahex',
    'ASCII_Hex_Digit',

    'Alphabetic',

    'Cased',

    'cwcf',
    'Changes_When_Casefolded',

    'cwcm',
    'Changes_When_Casemapped',

    'cwl',
    'Changes_When_Lowercased',

    'cwt',
    'Changes_When_Titlecased',

    'cwu',
    'Changes_When_Uppercased',

    'ci',
    'Case_Ignorable',

    'bidic',
    'Bidi_Control',

    'Dash',

    'dep',
    'Deprecated',

    'di',
    'Default_Ignorable_Code_Point',

    'dia',
    'Diacritic',

    'ext',
    'Extender',

    'grbase',
    'Grapheme_Base',

    'grext',
    'Grapheme_Extend',

    'grlink',
    'Grapheme_Link',

    'hex',
    'Hex_Digit',

    'Hyphen',

    'idc',
    'ID_Continue',

    'ideo',
    'Ideographic',

    'ids',
    'ID_Start',

    'idsb',
    'IDS_Binary_Operator',

    'idst',
    'IDS_Trinary_Operator',

    'joinc',
    'Join_Control',

    'loe',
    'Logical_Order_Exception',

    'Lowercase',

    'Math',

    'nchar',
    'Noncharacter_Code_Point',

    'oalpha',
    'Other_Alphabetic',

    'odi',
    'Other_Default_Ignorable_Code_Point',

    'ogrext',
    'Other_Grapheme_Extend',

    'oidc',
    'Other_ID_Continue',

    'oids',
    'Other_ID_Start',

    'olower',
    'Other_Lowercase',

    'omath',
    'Other_Math',

    'oupper',
    'Other_Uppercase',

    'patsyn',
    'Pattern_Syntax',

    'patws',
    'Pattern_Whitespace',

    'qmark',
    'quotationmark',

    'radical',

    'ri',
    'Regional_Indicator',

    'sd',
    'Soft_Dotted',

    'sterm',

    'term',
    'Terminal_Punctuation',

    'uideo',
    'Unified_Ideograph',

    'Uppercase',

    'vs',
    'Variation_Selector',

    'wspace',
    'whitespace',

    'xids',
    'XID_Start',

    'xidc',
    'XID_Continue',

    'Emoji',
    'Emoji_Component',
    'Emoji_Modifier',
    'Emoji_Modifier_Base',
    'Emoji_Presentation',
  ]

  modes.each do |mode|
    token_type = mode == 'p' ? :property : :nonproperty

    props.each do |property|
      define_method "test_parse_#{token_type}_#{property}" do
        t = RP.parse "ab\\#{mode}{#{property}}", 'ruby/2.5'

        assert t.expressions.last.is_a?(UnicodeProperty::Base),
               "Expected property, but got #{t.expressions.last.class.name}"

        assert_equal token_type, t.expressions.last.type
        assert_equal property,   t.expressions.last.name
      end
    end
  end

  def test_parse_property_negative
    t = RP.parse 'ab\p{L}cd', 'ruby/1.9'

    assert_equal false, t.expressions[1].negative?
  end

  def test_parse_nonproperty_negative
    t = RP.parse 'ab\P{L}cd', 'ruby/1.9'

    assert_equal true, t.expressions[1].negative?
  end

  def test_parse_caret_nonproperty_negative
    t = RP.parse 'ab\p{^L}cd', 'ruby/1.9'

    assert_equal true, t.expressions[1].negative?
  end

  def test_parse_double_negated_property_negative
    t = RP.parse 'ab\P{^L}cd', 'ruby/1.9'

    assert_equal false, t.expressions[1].negative?
  end

  def test_parse_property_age
    t = RP.parse 'ab\p{age=5.2}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Age),
           "Expected Age property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_derived
    t = RP.parse 'ab\p{Math}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Derived),
           "Expected Derived property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_script
    t = RP.parse 'ab\p{Hiragana}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Script),
           "Expected Script property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_script_v193
    t = RP.parse 'ab\p{Brahmi}cd', 'ruby/1.9.3'

    assert t.expressions[1].is_a?(UnicodeProperty::Script),
           "Expected Script property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_script_v220
    t = RP.parse 'ab\p{Caucasian_Albanian}cd', 'ruby/2.2'

    assert t.expressions[1].is_a?(UnicodeProperty::Script),
           "Expected Script property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_block
    t = RP.parse 'ab\p{InArmenian}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Block),
           "Expected Block property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_following_literal
    t = RP.parse 'ab\p{Lu}cd', 'ruby/1.9'

    assert t.expressions[2].is_a?(Literal),
           "Expected Literal, but got #{t.expressions[2].class.name}"
  end
end

==> regexp_parser-0.5.0.tar.gz: regexp_parser-0.5.0/test/parser/test_properties.rb <==
require File.expand_path("../../helpers", __FILE__)

class ParserProperties < Test::Unit::TestCase

  modes = ['p', 'P']
  props = [
    'Alnum',
    'Alpha',
    'Ascii',
    'Blank',
    'Cntrl',
    'Digit',
    'Graph',
    'Lower',
    'Print',
    'Punct',
    'Space',
    'Upper',
    'Word',
    'Xdigit',
    'XPosixPunct',

    'Any',
    'Assigned',

    'L',
    'Letter',

    'Lu',
    'Uppercase_Letter',

    'Ll',
    'Lowercase_Letter',

    'Lt',
    'Titlecase_Letter',

    'Lm',
    'Modifier_Letter',

    'Lo',
    'Other_Letter',

    'M',
    'Mark',

    'Mn',
    'Nonspacing_Mark',

    'Mc',
    'Spacing_Mark',

    'Me',
    'Enclosing_Mark',

    'N',
    'Number',

    'Nd',
    'Decimal_Number',

    'Nl',
    'Letter_Number',

    'No',
    'Other_Number',

    'P',
    'Punctuation',

    'Pc',
    'Connector_Punctuation',

    'Pd',
    'Dash_Punctuation',

    'Ps',
    'Open_Punctuation',

    'Pe',
    'Close_Punctuation',

    'Pi',
    'Initial_Punctuation',

    'Pf',
    'Final_Punctuation',

    'Po',
    'Other_Punctuation',

    'S',
    'Symbol',

    'Sm',
    'Math_Symbol',

    'Sc',
    'Currency_Symbol',

    'Sk',
    'Modifier_Symbol',

    'So',
    'Other_Symbol',

    'Z',
    'Separator',

    'Zs',
    'Space_Separator',

    'Zl',
    'Line_Separator',

    'Zp',
    'Paragraph_Separator',

    'C',
    'Other',

    'Cc',
    'Control',

    'Cf',
    'Format',

    'Cs',
    'Surrogate',

    'Co',
    'Private_Use',

    'Cn',
    'Unassigned',

    'Age=1.1',
    'Age=2.0',
    'Age=2.1',
    'Age=3.0',
    'Age=3.1',
    'Age=3.2',
    'Age=4.0',
    'Age=4.1',
    'Age=5.0',
    'Age=5.1',
    'Age=5.2',
    'Age=6.0',
    'Age=7.0',
    'Age=8.0',
    'Age=9.0',
    'Age=10.0',

    'ahex',
    'ASCII_Hex_Digit',

    'Alphabetic',

    'Cased',

    'cwcf',
    'Changes_When_Casefolded',

    'cwcm',
    'Changes_When_Casemapped',

    'cwl',
    'Changes_When_Lowercased',

    'cwt',
    'Changes_When_Titlecased',

    'cwu',
    'Changes_When_Uppercased',

    'ci',
    'Case_Ignorable',

    'bidic',
    'Bidi_Control',

    'Dash',

    'dep',
    'Deprecated',

    'di',
    'Default_Ignorable_Code_Point',

    'dia',
    'Diacritic',

    'ext',
    'Extender',

    'grbase',
    'Grapheme_Base',

    'grext',
    'Grapheme_Extend',

    'grlink',
    'Grapheme_Link',

    'hex',
    'Hex_Digit',

    'Hyphen',

    'idc',
    'ID_Continue',

    'ideo',
    'Ideographic',

    'ids',
    'ID_Start',

    'idsb',
    'IDS_Binary_Operator',

    'idst',
    'IDS_Trinary_Operator',

    'joinc',
    'Join_Control',

    'loe',
    'Logical_Order_Exception',

    'Lowercase',

    'Math',

    'nchar',
    'Noncharacter_Code_Point',

    'oalpha',
    'Other_Alphabetic',

    'odi',
    'Other_Default_Ignorable_Code_Point',

    'ogrext',
    'Other_Grapheme_Extend',

    'oidc',
    'Other_ID_Continue',

    'oids',
    'Other_ID_Start',

    'olower',
    'Other_Lowercase',

    'omath',
    'Other_Math',

    'oupper',
    'Other_Uppercase',

    'patsyn',
    'Pattern_Syntax',

    'patws',
    'Pattern_Whitespace',

    'qmark',
    'quotationmark',

    'radical',

    'ri',
    'Regional_Indicator',

    'sd',
    'Soft_Dotted',

    'sterm',

    'term',
    'Terminal_Punctuation',

    'uideo',
    'Unified_Ideograph',

    'Uppercase',

    'vs',
    'Variation_Selector',

    'wspace',
    'whitespace',

    'xids',
    'XID_Start',

    'xidc',
    'XID_Continue',

    'Emoji',
    'Emoji_Component',
    'Emoji_Modifier',
    'Emoji_Modifier_Base',
    'Emoji_Presentation',
  ]

  modes.each do |mode|
    token_type = mode == 'p' ? :property : :nonproperty

    props.each do |property|
      define_method "test_parse_#{token_type}_#{property}" do
        t = RP.parse "ab\\#{mode}{#{property}}", 'ruby/2.5'

        assert t.expressions.last.is_a?(UnicodeProperty::Base),
               "Expected property, but got #{t.expressions.last.class.name}"

        assert_equal token_type, t.expressions.last.type
        assert_equal property,   t.expressions.last.name
      end
    end
  end

  def test_parse_property_negative
    t = RP.parse 'ab\p{L}cd', 'ruby/1.9'

    assert_equal false, t.expressions[1].negative?
  end

  def test_parse_nonproperty_negative
    t = RP.parse 'ab\P{L}cd', 'ruby/1.9'

    assert_equal true, t.expressions[1].negative?
  end

  def test_parse_caret_nonproperty_negative
    t = RP.parse 'ab\p{^L}cd', 'ruby/1.9'

    assert_equal true, t.expressions[1].negative?
  end

  def test_parse_double_negated_property_negative
    t = RP.parse 'ab\P{^L}cd', 'ruby/1.9'

    assert_equal false, t.expressions[1].negative?
  end

  def test_parse_property_age
    t = RP.parse 'ab\p{age=5.2}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Age),
           "Expected Age property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_derived
    t = RP.parse 'ab\p{Math}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Derived),
           "Expected Derived property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_script
    t = RP.parse 'ab\p{Hiragana}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Script),
           "Expected Script property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_script_V1_9_3
    t = RP.parse 'ab\p{Brahmi}cd', 'ruby/1.9.3'

    assert t.expressions[1].is_a?(UnicodeProperty::Script),
           "Expected Script property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_script_V2_2_0
    t = RP.parse 'ab\p{Caucasian_Albanian}cd', 'ruby/2.2'

    assert t.expressions[1].is_a?(UnicodeProperty::Script),
           "Expected Script property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_block
    t = RP.parse 'ab\p{InArmenian}cd', 'ruby/1.9'

    assert t.expressions[1].is_a?(UnicodeProperty::Block),
           "Expected Block property, but got #{t.expressions[1].class.name}"
  end

  def test_parse_property_following_literal
    t = RP.parse 'ab\p{Lu}cd', 'ruby/1.9'

    assert t.expressions[2].is_a?(Literal),
           "Expected Literal, but got #{t.expressions[2].class.name}"
  end

  def test_parse_abandoned_newline_property
    t = RP.parse '\p{newline}', 'ruby/1.9'
    assert t.expressions.last.is_a?(UnicodeProperty::Base),
           "Expected property, but got #{t.expressions.last.class.name}"

    assert_raise(Regexp::Syntax::NotImplementedError) {
      RP.parse('\p{newline}', 'ruby/2.0')
    }
  end
end
